/*
** Copyright (C) 10 Feb 1999 Jonas Munsin <jmunsin@iki.fi>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

extern char *cdrecord_path;
extern char *mkisofs_path;
extern char *diff_path;
extern int no_of_tracks;
extern char *isocdrom_device_path;

cmd_v *make_cdrecord_command(config_cdr_data *);
cmd_v *make_blank_command(config_cdr_data *);
cmd_v *make_mkisofs_command(int, char *, config_cdr_data *);
cmd_v *make_mkisofs_c_optimize(file_data *c[], int i);
cmd_v *make_cdrecord_read_atip_command(config_cdr_data *);
cmd_v *make_cdrecord_trayaction_command(config_cdr_data *, guint);

cmd_v *make_cdrecord_cmd_for_audio_track(config_cdr_data *);
cmd_v *make_cdrecord_cmd_for_audio_track_fixate(config_cdr_data *);
GSList *make_cdda2wav_list_cmd(void);
char *get_last_session_info(config_cdr_data *);

int check_if_exe_ok(char *);

enum {
	TRAY_EJECT,
	TRAY_CLOSE
};
